@@ -14,4 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.comparison import petrinet
+
+import pkgutil
+
+if pkgutil.find_loader("matplotlib"):
+    from pm4py.algo.comparison import petrinet
