@@ -14,4 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.conformance.alignments import decomposed, dfg, edit_distance, petri_net
+from pm4py.algo.conformance.alignments import decomposed, dfg, petri_net, process_tree
+import pkgutil
+
+if pkgutil.find_loader("stringdist"):
+    from pm4py.algo.conformance.alignments import edit_distance
