@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.transformation import log_to_trie, log_to_features
+from pm4py.algo.transformation import log_to_trie, log_to_features, ocel
 import pkgutil
 if pkgutil.find_loader("intervaltree"):
     from pm4py.algo.transformation import log_to_interval_tree
