@@ -14,7 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from typing import Optional, Dict, Any
+
+from typing import Dict
 
 from pm4py.objects.log.obj import EventLog
 from pm4py.util import xes_constants as xes
@@ -113,7 +114,7 @@ def form_encoding_dictio_from_log(log, parameters=None):
     return mapping
 
 
-def form_encoding_dictio_from_two_logs(log1: EventLog, log2: EventLog, parameters: Optional[Dict[str, Any]] = None) -> \
+def form_encoding_dictio_from_two_logs(log1: EventLog, log2: EventLog, parameters=None) -> \
 Dict[str, str]:
     """
     Forms the encoding dictionary from a couple of logs
