@@ -89,7 +89,7 @@ class OCEL(object):
         ret.append("\n")
         ret.append("Activities occurrences: " + str(self.events[self.event_activity].value_counts().to_dict()))
         ret.append("\n")
-        ret.append("Object types occurrences: " + str(self.objects[self.object_type_column].value_counts().to_dict()))
+        ret.append("Object types occurrences (number of objects): " + str(self.objects[self.object_type_column].value_counts().to_dict()))
         ret.append("\n")
         ret.append(
             "Please use <THIS>.get_extended_table() to get a dataframe representation of the events related to the objects.")
@@ -104,6 +104,6 @@ class OCEL(object):
     def __copy__(self):
         return OCEL(self.events, self.objects, self.relations, copy(self.globals), copy(self.parameters))
 
-    def __deepcopy__(self):
+    def __deepcopy__(self, memo):
         return OCEL(self.events.copy(), self.objects.copy(), self.relations.copy(), deepcopy(self.globals),
                     deepcopy(self.parameters))
