@@ -15,7 +15,10 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 import re
+import deprecation
 
+
+@deprecation.deprecated("2.2.11", "3.0.0", details="removed")
 def check_reg_matching(reg, stringa):
     """
     Check if a regular expression matches a given string
@@ -56,6 +59,7 @@ def check_reg_matching(reg, stringa):
         return False
 
 
+@deprecation.deprecated("2.2.11", "3.0.0", details="removed")
 def regex_replace_mapping(reg_stri, mapping, special_char="@@", parameters=None):
     """
     Replace strings in a regex given the mapping
@@ -89,6 +93,7 @@ def regex_replace_mapping(reg_stri, mapping, special_char="@@", parameters=None)
 
     return reg
 
+
 def get_new_char(label, shared_obj):
     """
     Get a new single character describing the activity, for the regex
