@@ -158,7 +158,7 @@ def get_shortest_paths(net, enable_extension=False):
 
 
 def get_decorations_from_dfg_spaths_acticount(net, dfg, spaths, activities_count, variant="frequency",
-                                              aggregation_measure=None):
+                                              aggregation_measure=None, stat_locale: dict = {}):
     """
     Get decorations from Petrinet without doing any replay
     but based on DFG measures, shortest paths and activities count.
@@ -179,7 +179,9 @@ def get_decorations_from_dfg_spaths_acticount(net, dfg, spaths, activities_count
         Describe how to decorate the Petri net (could be frequency or performance)
     aggregation_measure
         Specifies the aggregation measure
-
+    stat_locale
+        Dict to locale the stat strings
+    
     Returns
     -----------
     decorations
@@ -226,7 +228,7 @@ def get_decorations_from_dfg_spaths_acticount(net, dfg, spaths, activities_count
         arcs_max_value = max(list(decorations_int.values()))
         for arc in decorations_int:
             if "performance" in variant:
-                arc_label = human_readable_stat(decorations_int[arc])
+                arc_label = human_readable_stat(decorations_int[arc], stat_locale)
             else:
                 arc_label = str(decorations_int[arc])
             decorations[arc] = {"label": arc_label,
